{% if theme_gittip_user %}
<h3>Donate</h3>
<p>
Consider supporting the authors on <a href="https://www.gittip.com/">Gittip</a>:
<iframe style="border: 0; margin: 5px 0 -5px 0; padding: 0;"
   src="https://www.gittip.com/{{ theme_gittip_user }}/widget.html"
   width="48pt" height="20pt"></iframe>
</p>
{% endif %}
